@@ -701,7 +701,12 @@ int32_t sortClusterChain(struct sFileSystem *fs, u_int32_t cluster, const char (
 
 	u_int32_t match;
 
-	match=matchesDirPathLists(OPT_INCL_DIRS, OPT_INCL_DIRS_REC, OPT_EXCL_DIRS, OPT_EXCL_DIRS_REC, path);
+	if (!OPT_REGEX) {
+		match=matchesDirPathLists(OPT_INCL_DIRS, OPT_INCL_DIRS_REC, OPT_EXCL_DIRS, OPT_EXCL_DIRS_REC, path);
+	} else {
+		match=!matchesRegExList(OPT_REGEX_EXCL, (const char *) path);
+		if (OPT_REGEX_INCL->next != NULL) match &= matchesRegExList(OPT_REGEX_INCL, (const char *) path);
+	}
 
 	if ((ClusterChain=newClusterChain()) == NULL) {
 		myerror("Failed to generate new ClusterChain!");
@@ -787,11 +792,16 @@ int32_t sortFAT1xRootDirectory(struct sFileSystem *fs) {
 
 	u_int32_t match;
 
-	match=matchesDirPathLists(OPT_INCL_DIRS,
-				OPT_INCL_DIRS_REC,
-				OPT_EXCL_DIRS,
-				OPT_EXCL_DIRS_REC,
-				(const char(*)[MAX_PATH_LEN+1]) "/");
+	if (!OPT_REGEX) {
+		match=matchesDirPathLists(OPT_INCL_DIRS,
+					OPT_INCL_DIRS_REC,
+					OPT_EXCL_DIRS,
+					OPT_EXCL_DIRS_REC,
+					(const char(*)[MAX_PATH_LEN+1]) "/");
+	} else {
+		match=!matchesRegExList(OPT_REGEX_EXCL, (const char *) "/");
+		if (OPT_REGEX_INCL->next != NULL) match &= matchesRegExList(OPT_REGEX_INCL, (const char *) "/");
+	}
 
 	if (!OPT_LIST) {
 		if (match) {
